NAME
Sisimai::Reason::Suspend - Bounce reason is suspend or not.
SYNOPSIS
use Sisimai::Reason::Suspend;
print Sisimai::Reason::Suspend->match('recipient suspend the service'); # 1
DESCRIPTION
Sisimai::Reason::Suspend checks the bounce reason is suspend or not. This class is called only Sisimai::Reason class.
CLASS METHODS
text()
text() returns string: suspend.
print Sisimai::Reason::Suspend->text; # suspend
match( string )
match() returns 1 if the argument matched with patterns defined in this class.
print Sisimai::Reason::Suspend->match('recipient suspend the service'); # 1
true( Sisimai::Data )
true() returns 1 if the bounce reason is suspend. The argument must be Sisimai::Data object and this method is called only from Sisimai::Reason class.
AUTHOR
azumakuniyuki
COPYRIGHT
Copyright (C) 2014 azumakuniyuki <perl.org@azumakuniyuki.org>, All Rights Reserved.
LICENSE
This software is distributed under The BSD 2-Clause License.